import { world } from "@minecraft/server";
import { ActionFormData } from "@minecraft/server-ui";
import { ModalFormData } from "@minecraft/server-ui";

function showUI(player) {

    const isTurnedOn = player.hasTag("mstop");

    
    const ui = new ModalFormData()
        .title("§l§4Time Stop Clock") 
        .toggle("§l§6Time Stop", isTurnedOn); 

    
    ui.show(player).then(response => {
        if (response.canceled) return; 

        const toggleState = response.formValues[0]; 

        if (toggleState && !isTurnedOn) {
            enableTimeStop(player); 
        } else if (!toggleState && isTurnedOn) {
            disableTimeStop(player); 
        }
    });
}

function enableTimeStop(player) {
    if (player.hasTag("mstop")) return; 

    player.addTag("mstop"); 
    player.runCommandAsync(`tellraw @s {"rawtext":[{"text":"§a§lTime Stop Enabled!"}]}`);
}

function disableTimeStop(player) {
    if (!player.hasTag("mstop")) return; 

    player.removeTag("mstop"); 
    player.runCommandAsync(`tellraw @s {"rawtext":[{"text":"§c§lTime Stop Disabled!"}]}`);
}


world.afterEvents.itemUse.subscribe((event) => {
    const { source, itemStack } = event;

    if (itemStack.typeId === "zc:mstop") {
        showUI(source); 
    }
});


world.beforeEvents.playerLeave.subscribe((event) => {
    const player = event.player;

    if (player.hasTag("mstop")) {
        disableTimeStop(player); 
    }
});




const ui = new ActionFormData()
    .title("§l§4Select Your Team or Action") 
    .body("§l§6Choose an option below:") 
    .button("§l§5Team A") 
    .button("§l§5Team B") 
    .button("§l§5Team C") 
    .button("§l§5Team D") 
    .button("§l§5Battle Round 1") 
    .button("§l§5Battle Round 2") 
    .button("§l§5Kill All"); 

world.afterEvents.itemUse.subscribe((event) => {
    const { source, itemStack } = event;

    if (itemStack.typeId === "zc:mbw") { 
        ui.show(source).then(async (response) => {
            if (response.canceled) return; 

            try {
                switch (response.selection) {
                    case 0: // Team A
                        await source.runCommandAsync(
                            `execute @e[r=7,tag=!a] ~~~ tag @s[tag=!b,tag=!c,tag=!d] add a`
                        );
                        await source.runCommandAsync(`tag @p remove a`);
                        await source.runCommandAsync(`tag @e[type=item] remove a`);
                        await source.runCommandAsync(`execute @e[r=7,tag=a] ~~~ say is Team A`);
                        break;

                    case 1: // Team B
                        await source.runCommandAsync(
                            `execute @e[r=7,tag=!b] ~~~ tag @s[tag=!a,tag=!c,tag=!d] add b`
                        );
                        await source.runCommandAsync(`tag @p remove b`);
                        await source.runCommandAsync(`tag @e[type=item] remove b`);
                        await source.runCommandAsync(`execute @e[r=7,tag=b] ~~~ say is Team B`);
                        break;

                    case 2: // Team C
                        await source.runCommandAsync(
                            `execute @e[r=7,tag=!c] ~~~ tag @s[tag=!a,tag=!b,tag=!d] add c`
                        );
                        await source.runCommandAsync(`tag @p remove c`);
                        await source.runCommandAsync(`tag @e[type=item] remove c`);
                        await source.runCommandAsync(`execute @e[r=7,tag=c] ~~~ say is Team C`);
                        break;

                    case 3: // Team D
                        await source.runCommandAsync(
                            `execute @e[r=7,tag=!d] ~~~ tag @s[tag=!a,tag=!b,tag=!c] add d`
                        );
                        await source.runCommandAsync(`tag @p remove d`);
                        await source.runCommandAsync(`tag @e[type=item] remove d`);
                        await source.runCommandAsync(`execute @e[r=7,tag=d] ~~~ say is Team D`);
                        break;

                    case 4: // Battle Round 1
                    await source.runCommandAsync(
                            `title @a title §l§4Round 1`
                        );
                        await source.runCommandAsync(
                            `title @a subtitle §bFight with honor`
                        );
                        await source.runCommandAsync(
                            `damage @e[tag=a,c=1] 1 entity_attack entity @e[tag=b]`
                        );
                        await source.runCommandAsync(
                            `damage @e[tag=b,c=1] 1 entity_attack entity @e[tag=a]`
                        );
                        
                        await source.runCommandAsync(
                            `damage @e[tag=c,c=1] 1 entity_attack entity @e[tag=d]`
                        );
                        await source.runCommandAsync(
                            `damage @e[tag=d,c=1] 1 entity_attack entity @e[tag=c]`
                        );
                        await source.runCommandAsync(`tag @a remove mstop`);
                        break;
                    case 5: // Start Battle Round 2
                    await source.runCommandAsync(
                            `title @a title §l§4Round 2`
                        );
                        await source.runCommandAsync(
                            `title @a subtitle §bProve yourself`
                        );
                        await source.runCommandAsync(
                            `damage @e[tag=a,c=1] 1 entity_attack entity @e[tag=d]`
                        );
                        await source.runCommandAsync(
                            `damage @e[tag=a,c=1] 1 entity_attack entity @e[tag=c]`
                        );
                        
                        await source.runCommandAsync(
                            `damage @e[tag=d,c=1] 1 entity_attack entity @e[tag=a]`
                        );
                        await source.runCommandAsync(
                            `damage @e[tag=c,c=1] 1 entity_attack entity @e[tag=a]`
                        );
                        // Battle Round 2 B
                        await source.runCommandAsync(
                            `damage @e[tag=b,c=1] 1 entity_attack entity @e[tag=d]`
                        );
                        await source.runCommandAsync(
                            `damage @e[tag=b,c=1] 1 entity_attack entity @e[tag=c]`
                        );
                        
                        await source.runCommandAsync(
                            `damage @e[tag=d,c=1] 1 entity_attack entity @e[tag=b]`
                        );
                        await source.runCommandAsync(
                            `damage @e[tag=c,c=1] 1 entity_attack entity @e[tag=b]`
                        );
                        await source.runCommandAsync(`tag @a remove mstop`);
                        break;
                    case 6: // Kill All Entities
                        await source.runCommandAsync(`kill @e`);
                        await source.runCommandAsync(`tellraw @s {"rawtext":[{"text":"§cAll entities have been killed!"}]}`);
                        break;
                    default:
                        source.runCommandAsync(`tellraw @s {"rawtext":[{"text":"§cInvalid choice."}]}`);
                        break;
                }
            } catch (error) {
                source.runCommandAsync(`tellraw @s {"rawtext":[{"text":"§cAn error occurred while running the command."}]}`);
                console.error(error);
            }
        });
    }
});







function showPageSelectionUI(player) {
    const ui = new ActionFormData()
        .title("§l§4Mob Battle Guide") 
        .body("§l§6Choose a page to proceed.") 
        .button("§l§5Page 1", "textures/items/paper")
        .button("§l§5Page 2", "textures/items/paper")
        .button("§l§5Page 3", "textures/items/paper")
        .button("§l§5Page 4", "textures/items/paper")
        .button("§l§5Page 5", "textures/items/paper")
        .button("§l§5Page 6", "textures/items/paper");

    ui.show(player).then(response => {
        if (response.canceled) return;

        switch (response.selection) {
            case 0:
                showPage1UI(player);
                break;
            case 1:
                showPage2UI(player);
                break;
            case 2:
                showPage3UI(player);
                break;
            case 3:
                showPage4UI(player);
                break;
            case 4:
                showPage5UI(player);
                break;
            case 5:
                showPage6UI(player);
                break;
        }
    });
}


function showPage1UI(player) {
    const ui = new ActionFormData()
        .title("§l§4Page 1 - Turn Off Mob Spawning")
        .body("§l§6Disable Mob Spawning to work perfectly, then open Page 2.")
        .button("§l§5Disable Mob Spawn", "textures/items/ominous_bottle")
        .button("§l§5Back", "textures/items/arrow");

    ui.show(player).then(response => {
        if (response.canceled) return;

        if (response.selection === 0) {
            player.runCommandAsync("gamerule domobspawning false");
            player.runCommandAsync(`tellraw @s {"rawtext":[{"text":"§cMob Spawn Disabled!"}]}`);
            showPageSelectionUI(player);
        } else {
            showPageSelectionUI(player);
        }
    });
}


function showPage2UI(player) {
    const ui = new ActionFormData()
        .title("§l§4Page 2 - Clear Entities")
        .body("§l§6Click the Kill Button to clear unnecessary entities.")
        .button("§l§5Kill Entities", "textures/items/diamond_sword")
        .button("§l§5Back", "textures/items/arrow");

    ui.show(player).then(response => {
        if (response.canceled) return;

        if (response.selection === 0) {
            player.runCommandAsync("kill @e");
            player.runCommandAsync(`tellraw @s {"rawtext":[{"text":"§cEntities Cleared!"}]}`);
            showPageSelectionUI(player);
        } else {
            showPageSelectionUI(player);
        }
    });
}


function showPage3UI(player) {
    const ui = new ActionFormData()
        .title("§l§4Page 3 - Time Stop")
        .body("§l§6Use the Time Clock to stop time.")
        .button("§l§5Back", "textures/items/arrow");

    ui.show(player).then(response => {
        if (response.canceled) return;

        showPageSelectionUI(player);
    });
}


function showPage4UI(player) {
    const ui = new ActionFormData()
        .title("§l§4Page 4 - Team A Setup")
        .body("§l§6Spawn the first mob, then use the Battle Wand to select Team A.")
        .button("§l§5Back", "textures/items/arrow");

    ui.show(player).then(response => {
        if (response.canceled) return;

        showPageSelectionUI(player);
    });
}


function showPage5UI(player) {
    const ui = new ActionFormData()
        .title("§l§4Page 5 - Team B Setup")
        .body("§l§6Spawn the second mob, then use the Battle Wand to select Team B.")
        .button("§l§5Back", "textures/items/arrow");

    ui.show(player).then(response => {
        if (response.canceled) return;

        showPageSelectionUI(player);
    });
}


function showPage6UI(player) {
    const ui = new ActionFormData()
        .title("§l§4Page 6 - Battle Setup")
        .body(
            "§l§6Use the Battle Wand and click on Battle.\n" +
            "After the battle ends, use the Kill Button to clear entities."
        )
        .button("§l§5Back", "textures/items/arrow");

    ui.show(player).then(response => {
        if (response.canceled) return;

        showPageSelectionUI(player);
    });
}


world.afterEvents.itemUse.subscribe(event => {
    const { source, itemStack } = event;

    if (itemStack.typeId === "zc:mbg") {
        showPageSelectionUI(source);
    }
});
